package org.greenstone.gsdl3_extension.mat.servlet;

import java.io.*;
import java.io.File;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.HashMap;
import java.util.Iterator;

import org.w3c.dom.Element;
import org.greenstone.gsdl3.core.MessageRouter;
import org.greenstone.gsdl3.util.GlobalProperties;
import org.greenstone.gsdl3.util.GSFile;
import org.greenstone.gsdl3.util.GDBMWrapper;

public class DescribeMessager {
    
    private final String site_name = "localsite";
    private MessageRouter mr = null;
    private String collection_Name = null;
    private MetadataStats ms;
    private String site_home = null;
    private String gsdl3_home = null;
    
    public DescribeMessager(String collectionName, String URL) {
	
    	collection_Name = collectionName; 	
    	gsdl3_home = GlobalProperties.getGSDL3Home();
    
    	if (gsdl3_home == null || gsdl3_home.equals("")) {
    	    System.err.println("Couldn't access GSDL3Home from GlobalProperties.getGSDL3HOME, can't initialize the SOAP Server.");
    	    return;
    	}
    	
    	site_home = GSFile.siteHome(gsdl3_home, this.site_name);
    	
    	File site_file = new File(site_home);
	
    	if (!site_file.isDirectory()) {
    	    System.err.println("The site directory "+site_file.getPath()+" doesn't exist. Can't initialize the SOAP Server.");
    	    return;
    	} 
    	
    	mr = new MessageRouter();
    	mr.setSiteName(this.site_name);
    	mr.configure();
    }
    
    public void setCollectionName(String arg){
    	collection_Name = arg;
    }
    
    public String getCollectionName(){
    	return collection_Name;
    }

    public boolean describeMatadata(PrintWriter out, String collectionName,String OAIURL, String oaiPrefix){
	
	ms = new MetadataStats(this.site_home,collectionName,OAIURL,out, oaiPrefix);
    	
	if(ms.getStatus()){
	    printWebPage(ms,out);
	    return true;
	}
     	else{
	    out.print("<p> This collection could not be analysed.</p>");
	    return false;
	}
    }

    public void printWebPage(MetadataStats ms,PrintWriter out){
	
    	DataMaker dm = new DataMaker(ms);
    	String[] elements =  new String [ms.metadataNameList.size()];
        
    	for(int i = 0; i<elements.length; i++){
    		elements[i] = (String)ms.metadataNameList.get(i);
        }
	
        Arrays.sort(elements);
	
        /*
    	String[] metaDataElementName = (String[])elements.clone();	
    	String[] ids = dm.getDocumentIDs("archivedir");
		ArrayList alist = new ArrayList();
    	
		for(int a = 0; a<elements.length; a++){
	    	alist.add(dm.getMetadataRows(elements[a]));
    	}
		*/
        
    	PrintHTML phtml = new PrintHTML(ms,out);
    	HashMap hp = ms.getMetadataSetMap();
    	Collection c = hp.values();
    	Iterator i = c.iterator();

    	while(i.hasNext()){
	    MetadataSet mds  = (MetadataSet)i.next();
	    ArrayList elementList = mds.getIndexsList();
	    String[] mdsElement = new String[elementList.size()];
	    
	    for(int x = 0; x<mdsElement.length; x++){
		mdsElement[x]=(String)elementList.get(x);
	    }
	    
	    Arrays.sort(mdsElement);
	    
	    String[] metaDataElement = (String[])mdsElement.clone();	
	    String[] idList = dm.getDocumentIDs("archivedir");
	    ArrayList datalist = new ArrayList();
        	
	    for(int a = 0; a<mdsElement.length; a++){
	    	datalist.add(dm.getMetadataRows(mdsElement[a]));
	    }
	    phtml.generateAllPossibleGraph(datalist,idList,metaDataElement,mds.getName());
	}
    	
	phtml.generateOverallStatisticsPage(hp);

    	Collection cx = ms.getMetadataSetMap().values();
    	Iterator ix = cx.iterator();

    	while(ix.hasNext()){
	    MetadataSet temp = (MetadataSet)ix.next();
	    phtml.WriteMetadataSetDetailHTML(temp);
	    phtml.generateMetadataElementDetailPage(temp,out);
	}
    }
 
    public MetadataStats getElementClass(){
    	return ms;
    }
    
    /*
      public static void main(String[] args) {
      DescribeMessager dm = new DescribeMessager("testCOLLECTION","cs.waikato.ac.nz");
      }
    */
}

